==> wiki3_4_0.zip: wiki3_4_0/plugin/attach/Files.pm <==
package plugin::attach::Files;
use plugin::attach::AttachHandler;
############################################################
#
# ΥڡźդƤեɽޤ
# FooterMenu˵ҤƤǤ
# <pre>
# {{files}}
# </pre>
# Menu˵ҤʤɡvץĤȽĤɽ뤳ȤǤޤ
# <pre>
# {{files v}}
# </pre>
#
############################################################
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# źեեΰɽ륤饤ؿ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $way  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if($pagename eq ""){
		return "";
	}
	
	my ($entry,$buf);
	
	my $editFlag = 1;
	my $login = $wiki->get_login_info();
	if($wiki->is_freeze($pagename) && (!defined($login) || $login->{type}!=0)){
		$editFlag = 0;
	} elsif((!$main::accept_edit || !$main::accept_attach_delete) && !defined($login)){
		$editFlag = 0;
	}
	
	if($way eq "V" || $way eq "v"){
		$buf = "<ul>\n";
	}
	
	foreach my $file (&get_file_list($pagename)){
		if($way eq "V" || $way eq "v"){
			$buf = $buf."<li><img src=\"images/clip.gif\">".
			       "<a href=\"$main::script_name?action=ATTACH&amp;DL=true&amp;page=".
			       Util::url_encode($pagename)."&amp;file=".Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		} else {
			$buf = $buf."<img src=\"images/clip.gif\">".
			       "<a href=\"$main::script_name?action=ATTACH&amp;DL=true&amp;page=".
			       Util::url_encode($pagename)."&amp;file=".Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		}
		
		if($editFlag){
			$buf .= "[<a href=\"$main::script_name?action=ATTACH&CONFIRM=yes&page=".Util::url_encode($pagename).
			        "&file=".$file."\"></a>]";
		}
		
		if($way eq "V" || $way eq "v"){
			$buf .= "</li>\n";
		} else {
			$buf .= "\n";
		}
	}
	
	if($way eq "V" || $way eq "v"){
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

#===========================================================
# եΰؿ
#===========================================================
sub get_file_list {
	my $page = shift;
	my $encode_page = Util::url_encode($page);
	my @list;
	if(-e $main::attach_dir){
		opendir(DIR,$main::attach_dir) or die $!;
		while(my $entry = readdir(DIR)){
			if(index($entry,$encode_page.".")==0){
				my $file = (split(/\./,$entry))[1];
				push(@list,Util::url_decode($file));
			}
		}
		closedir(DIR);
	}
	@list = sort { $a cmp $b } @list;
	return @list;
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/attach/Files.pm <==
############################################################
#
# ΥڡźդƤեɽޤ
# FooterMenu˵ҤƤǤ
# <pre>
# {{files}}
# </pre>
# Menu˵ҤʤɡvץĤȽĤɽ뤳ȤǤޤ
# <pre>
# {{files v}}
# </pre>
#
############################################################
package plugin::attach::Files;
use strict;
use lib "../../";
use plugin::attach::AttachHandler;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# źեեΰɽ륤饤ؿ
#===========================================================
sub inline {
	my $self = shift;
	my $wiki = shift;
	my $way  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if($pagename eq ""){
		return "";
	}
	
	my ($entry,$buf);
	
	my $editFlag = 1;
	my $login = $wiki->get_login_info();
	if($wiki->is_freeze($pagename) && (!defined($login) || $login->{type}!=0)){
		$editFlag = 0;
	} elsif(($wiki->config('accept_edit')==0 || $wiki->config('accept_attach_delete')==0) && !defined($login)){
		$editFlag = 0;
	}
	
	if($way eq "V" || $way eq "v"){
		$buf = "<ul>\n";
	}
	
	foreach my $file (&get_file_list($wiki,$pagename)){
		if($way eq "V" || $way eq "v"){
			$buf = $buf."<li><a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;DL=true&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		} else {
			$buf = $buf."<a href=\"".$wiki->config('script_name')."?action=ATTACH&amp;DL=true&amp;page=".
			       &Util::url_encode($pagename)."&amp;file=".&Util::url_encode($file)."\">".
			       $cgi->escapeHTML($file)."</a>";
		}
		
		if($editFlag){
			$buf .= "[<a href=\"".$wiki->config('script_name')."?action=ATTACH&CONFIRM=yes&page=".
			        &Util::url_encode($pagename)."&file=".&Util::url_encode($file)."\"></a>]";
		}
		
		if($way eq "V" || $way eq "v"){
			$buf .= "</li>\n";
		} else {
			$buf .= "\n";
		}
	}
	
	if($way eq "V" || $way eq "v"){
		$buf .= "</ul>\n";
	}
	
	return $buf;
}

#===========================================================
# եΰؿ
#===========================================================
sub get_file_list {
	my $wiki = shift;
	my $page = shift;
	my $encode_page = &Util::url_encode($page);
	my @list;
	if(-e $wiki->config('attach_dir')){
		opendir(DIR,$wiki->config('attach_dir')) or die $!;
		while(my $entry = readdir(DIR)){
			if(index($entry,$encode_page.".")==0){
				my $file = (split(/\./,$entry))[1];
				push(@list,&Util::url_decode($file));
			}
		}
		closedir(DIR);
	}
	@list = sort { $a cmp $b } @list;
	return @list;
}

1;
